@@ -188,7 +188,7 @@ purple_media_codec_class_init(PurpleMediaCodecClass *klass)
 	g_object_class_install_property(gobject_class, PROP_MEDIA_TYPE,
 			g_param_spec_flags("media-type",
 			"Media Type",
-			"Whether this is an audio of video codec.",
+			"Whether this is an audio, video or application codec.",
 			PURPLE_TYPE_MEDIA_SESSION_TYPE,
 			PURPLE_MEDIA_NONE,
 			G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE));
@@ -388,7 +388,6 @@ purple_media_codec_to_string(const PurpleMediaCodec *codec)
 	PurpleMediaCodecPrivate *priv;
 	GString *string = NULL;
 	GList *item;
-	gchar *charstring;
 	const gchar *media_type_str = NULL;
 
 	if (codec == NULL)
@@ -402,6 +401,8 @@ purple_media_codec_to_string(const PurpleMediaCodec *codec)
 		media_type_str = "audio";
 	else if (priv->media_type & PURPLE_MEDIA_VIDEO)
 		media_type_str = "video";
+	else if (priv->media_type & PURPLE_MEDIA_APPLICATION)
+		media_type_str = "application";
 
 	g_string_printf(string, "%d: %s %s clock:%d channels:%d", priv->id,
 			media_type_str, priv->encoding_name,
@@ -413,9 +414,6 @@ purple_media_codec_to_string(const PurpleMediaCodec *codec)
 				param->key, (gchar *)param->value);
 	}
 
-	charstring = string->str;
-	g_string_free (string, FALSE);
-
-	return charstring;
+	return g_string_free(string, FALSE);
 }
 
