@@ -21,7 +21,8 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02111-1301  USA
 #
 
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
+
 import dbus
 
 bus = dbus.SessionBus()
