@@ -71,7 +71,14 @@ static char *irc_mask_nick(const char *mask)
 
 static char *irc_mask_userhost(const char *mask)
 {
-	return g_strdup(strchr(mask, '!') + 1);
+	char *sep = strchr(mask, '!');
+	char *host = "";
+
+	if(sep) {
+		host = sep + 1;
+	}
+
+	return g_strdup(host);
 }
 
 static void irc_chat_remove_buddy(PurpleConversation *convo, char *data[2])
@@ -1457,10 +1464,6 @@ irc_sasl_cb_simple(void *ctx, int id, const char **res, unsigned *len)
 	const char *saslname =
 		purple_account_get_string(irc->account, "saslname", NULL);
 
-	if(saslname == NULL || *saslname == '\0') {
-		saslname = purple_account_get_string(irc->account, "realname", "");
-	}
-
 	if(saslname == NULL || *saslname == '\0') {
 		saslname = purple_connection_get_display_name(gc);
 	}
@@ -1615,22 +1618,22 @@ irc_msg_cap(struct irc_conn *irc, const char *name, const char *from, char **arg
 	irc->sasl_cb = g_new0(sasl_callback_t, 5);
 
 	irc->sasl_cb[id].id = SASL_CB_AUTHNAME;
-	irc->sasl_cb[id].proc = irc_sasl_cb_simple;
+	irc->sasl_cb[id].proc = (void *)irc_sasl_cb_simple;
 	irc->sasl_cb[id].context = (void *)irc;
 	id++;
 
 	irc->sasl_cb[id].id = SASL_CB_USER;
-	irc->sasl_cb[id].proc = irc_sasl_cb_simple;
+	irc->sasl_cb[id].proc = (void *)irc_sasl_cb_simple;
 	irc->sasl_cb[id].context = (void *)irc;
 	id++;
 
 	irc->sasl_cb[id].id = SASL_CB_PASS;
-	irc->sasl_cb[id].proc = irc_sasl_cb_secret;
+	irc->sasl_cb[id].proc = (void *)irc_sasl_cb_secret;
 	irc->sasl_cb[id].context = (void *)irc;
 	id++;
 
 	irc->sasl_cb[id].id = SASL_CB_LOG;
-	irc->sasl_cb[id].proc = irc_sasl_cb_log;
+	irc->sasl_cb[id].proc = (void *)irc_sasl_cb_log;
 	irc->sasl_cb[id].context = (void *)irc;
 	id++;
 
