@@ -74,7 +74,7 @@ jabber_adhoc_got_buddy_list(JabberStream *js, const char *from, xmlnode *query)
 		JabberAdHocCommands *cmd;
 		if(item->type != XMLNODE_TYPE_TAG)
 			continue;
-		if(strcmp(item->name, "item"))
+		if(!purple_strequal(item->name, "item"))
 			continue;
 		cmd = g_new0(JabberAdHocCommands, 1);
 
@@ -125,7 +125,8 @@ static void do_adhoc_action_cb(JabberStream *js, xmlnode *result, const char *ac
 	xmlnode_set_attrib(command,"node",actionInfo->node);
 
 	/* cancel is handled differently on ad-hoc commands than regular forms */
-	if(!strcmp(xmlnode_get_namespace(result),"jabber:x:data") && !strcmp(xmlnode_get_attrib(result, "type"),"cancel")) {
+	if (purple_strequal(xmlnode_get_namespace(result), "jabber:x:data") &&
+			purple_strequal(xmlnode_get_attrib(result, "type"), "cancel")) {
 		xmlnode_set_attrib(command,"action","cancel");
 	} else {
 		if(actionhandle)
@@ -168,7 +169,7 @@ jabber_adhoc_parse(JabberStream *js, const char *from,
 	if(!status)
 		return;
 
-	if(!strcmp(status,"completed")) {
+	if(purple_strequal(status,"completed")) {
 		/* display result */
 		xmlnode *note = xmlnode_get_child(command,"note");
 
@@ -182,7 +183,7 @@ jabber_adhoc_parse(JabberStream *js, const char *from,
 			jabber_x_data_request(js, xdata, (jabber_x_data_cb)do_adhoc_ignoreme, NULL);
 		return;
 	}
-	if(!strcmp(status,"executing")) {
+	if(purple_strequal(status,"executing")) {
 		/* this command needs more steps */
 		xmlnode *actions, *action;
 		int actionindex = 0;
@@ -206,7 +207,7 @@ jabber_adhoc_parse(JabberStream *js, const char *from,
 					newaction->name = g_strdup(_(action->name));
 					newaction->handle = g_strdup(action->name);
 					actionslist = g_list_append(actionslist, newaction);
-					if(defaultactionhandle && !strcmp(defaultactionhandle, action->name))
+					if(defaultactionhandle && purple_strequal(defaultactionhandle, action->name))
 						actionindex = index;
 				}
 			}
@@ -256,7 +257,7 @@ jabber_adhoc_got_server_list(JabberStream *js, const char *from, xmlnode *query)
 		JabberAdHocCommands *cmd;
 		if(item->type != XMLNODE_TYPE_TAG)
 			continue;
-		if(strcmp(item->name, "item"))
+		if(!purple_strequal(item->name, "item"))
 			continue;
 		cmd = g_new0(JabberAdHocCommands, 1);
 		cmd->jid = g_strdup(xmlnode_get_attrib(item,"jid"));
