@@ -526,7 +526,7 @@ static void jabber_chat_room_configure_cb(JabberStream *js, const char *from,
 			if(!(xmlns = xmlnode_get_namespace(x)))
 				continue;
 
-			if(!strcmp(xmlns, "jabber:x:data")) {
+			if(purple_strequal(xmlns, "jabber:x:data")) {
 				chat->config_dialog_type = PURPLE_REQUEST_FIELDS;
 				chat->config_dialog_handle = jabber_x_data_request(js, x, jabber_chat_room_configure_x_data_cb, chat);
 				return;
@@ -671,7 +671,7 @@ static void jabber_chat_register_cb(JabberStream *js, const char *from,
 			if(!(xmlns = xmlnode_get_namespace(x)))
 				continue;
 
-			if(!strcmp(xmlns, "jabber:x:data")) {
+			if(purple_strequal(xmlns, "jabber:x:data")) {
 				jabber_x_data_request(js, x, jabber_chat_register_x_data_cb, chat);
 				return;
 			}
@@ -1226,7 +1226,7 @@ static void jabber_chat_disco_traffic_cb(JabberStream *js, const char *from,
 	for(x = xmlnode_get_child(query, "feature"); x; x = xmlnode_get_next_twin(x)) {
 		const char *var = xmlnode_get_attrib(x, "var");
 
-		if(var && !strcmp(var, NS_XHTML_IM)) {
+		if(purple_strequal(var, NS_XHTML_IM)) {
 			chat->xhtml = TRUE;
 		}
 	}
@@ -1275,7 +1275,8 @@ jabber_chat_all_participants_have_capability_foreach(gpointer key,
 	JabberBuddyResource *jbr = jabber_buddy_find_resource(jb, resource);
 
 	if (jbr) {
-		*all_support &= jabber_resource_has_capability(jbr, cap);
+		if (*all_support && jabber_resource_has_capability(jbr, cap))
+			*all_support = TRUE;
 	} else {
 		*all_support = FALSE;
 	}
