@@ -131,7 +131,10 @@ static PurplePluginProtocolInfo prpl_info =
 	NULL, /* set_public_alias */
 	NULL, /* get_public_alias */
 	NULL, /* add_buddy_with_invite */
-	NULL  /* add_buddies_with_invite */
+	NULL, /* add_buddies_with_invite */
+	NULL, /* get_cb_alias */
+	NULL, /* chat_can_receive_file */
+	NULL, /* chat_send_file */
 };
 
 static gboolean load_plugin(PurplePlugin *plugin)
