@@ -1526,7 +1526,7 @@ _handle_multiple_get_details_joinconf_cb(NMUser * user, NMERR_T ret_code,
 			if (nm_utf8_str_equal(nm_user_record_get_dn(user_record),
 								  (const char *) node->data)) {
 				g_free(node->data);
-				list = g_slist_remove(list, node->data);
+				list = g_slist_remove_link(list, node);
 				nm_request_set_user_define(request, list);
 				break;
 			}
