@@ -11,11 +11,10 @@
 #include "internal.h"
 #include "util.h"
 
-Code_t ZRequestLocations(user, zald, kind, auth)
-     const char *user;
-     ZAsyncLocateData_t *zald;
-     ZNotice_Kind_t kind;	/* UNSAFE, UNACKED, or ACKED */
-     Z_AuthProc auth;
+Code_t
+ZRequestLocations(const char *user, ZAsyncLocateData_t *zald,
+                  ZNotice_Kind_t kind, /* UNSAFE, UNACKED, or ACKED */
+                  Z_AuthProc auth)
 {
     int retval;
     ZNotice_t notice;
@@ -55,11 +54,9 @@ Code_t ZRequestLocations(user, zald, kind, auth)
     return(ZERR_NONE);
 }
 
-Code_t ZParseLocations(notice,zald,nlocs,user)
-     ZNotice_t *notice;
-     ZAsyncLocateData_t *zald;
-     int *nlocs;
-     char **user;
+Code_t
+ZParseLocations(ZNotice_t *notice, ZAsyncLocateData_t *zald, int *nlocs,
+                char **user)
 {
     char *ptr, *end;
     int i;
@@ -150,16 +147,15 @@ Code_t ZParseLocations(notice,zald,nlocs,user)
     return (ZERR_NONE);
 }
 
-int ZCompareALDPred(notice, zald)
-     ZNotice_t *notice;
-     void *zald;
+int
+ZCompareALDPred(ZNotice_t *notice, void *zald)
 {
     return(ZCompareUID(&(notice->z_multiuid),
 		       &(((ZAsyncLocateData_t *) zald)->uid)));
 }
 
-void ZFreeALD(zald)
-     ZAsyncLocateData_t *zald;
+void
+ZFreeALD(ZAsyncLocateData_t *zald)
 {
    if (!zald) return;
 
