@@ -5,18 +5,19 @@
  *
  *	Copyright (c) 1987 by the Massachusetts Institute of Technology.
  *	For copying and distribution information, see the file
- *	"mit-copyright.h". 
+ *	"mit-copyright.h".
  */
 
 #include "internal.h"
 
-Code_t ZClosePort()
+Code_t
+ZClosePort(void)
 {
     if (__Zephyr_fd >= 0 && __Zephyr_open)
 	(void) close(__Zephyr_fd);
 
     __Zephyr_fd = -1;
     __Zephyr_open = 0;
-	
+
     return (ZERR_NONE);
 }
