@@ -5,15 +5,13 @@
  *
  *	Copyright (c) 1987 by the Massachusetts Institute of Technology.
  *	For copying and distribution information, see the file
- *	"mit-copyright.h". 
+ *	"mit-copyright.h".
  */
 
 #include "internal.h"
 
-Code_t ZFormatRawNotice(notice, buffer, ret_len)
-    register ZNotice_t *notice;
-    char **buffer;
-    int *ret_len;
+Code_t
+ZFormatRawNotice(register ZNotice_t *notice, char **buffer, int *ret_len)
 {
     char header[Z_MAXHEADERLEN];
     int hdrlen;
