@@ -10,9 +10,8 @@
 
 #include "internal.h"
 
-Code_t ZPeekNotice(notice, from)
-    ZNotice_t *notice;
-    struct sockaddr_in *from;
+Code_t
+ZPeekNotice(ZNotice_t *notice, struct sockaddr_in *from)
 {
     char *buffer;
     int len;
