@@ -5,7 +5,7 @@
  *
  *	Copyright (c) 1987,1991 by the Massachusetts Institute of Technology.
  *	For copying and distribution information, see the file
- *	"mit-copyright.h". 
+ *	"mit-copyright.h".
  */
 
 #include "internal.h"
@@ -17,27 +17,25 @@
 
 static int wait_for_hmack(ZNotice_t *notice, void *uid);
 
-Code_t ZSendPacket(packet, len, waitforack)
-    char *packet;
-    int len;
-    int waitforack;
+Code_t
+ZSendPacket(char *packet, int len, int waitforack)
 {
     Code_t retval;
     struct sockaddr_in dest;
     ZNotice_t notice, acknotice;
-	
+
     if (!packet || len < 0)
 	return (ZERR_ILLVAL);
 
     if (len > Z_MAXPKTLEN)
 	return (ZERR_PKTLEN);
-    
+
     if (ZGetFD() < 0)
 	if ((retval = ZOpenPort((unsigned short *)0)) != ZERR_NONE)
 	    return (retval);
 
     dest = ZGetDestAddr();
-	
+
     if (sendto(ZGetFD(), packet, len, 0, (struct sockaddr *)&dest,
 	       sizeof(dest)) < 0)
 	return (errno);
@@ -47,7 +45,7 @@ Code_t ZSendPacket(packet, len, waitforack)
 
     if ((retval = ZParseNotice(packet, len, &notice)) != ZERR_NONE)
 	return (retval);
-    
+
     retval = Z_WaitForNotice (&acknotice, wait_for_hmack, &notice.z_uid,
 			      HM_TIMEOUT);
     if (retval == ETIMEDOUT)
