@@ -5,17 +5,17 @@
  *
  *	Copyright (c) 1987 by the Massachusetts Institute of Technology.
  *	For copying and distribution information, see the file
- *	"mit-copyright.h". 
+ *	"mit-copyright.h".
  */
 
 #include "internal.h"
 
-Code_t ZSetDestAddr(addr)
-	struct	sockaddr_in *addr;
+Code_t
+ZSetDestAddr(struct sockaddr_in *addr)
 {
 	__HM_addr = *addr;
 
 	__HM_set = 1;
-	
+
 	return (ZERR_NONE);
 }
