@@ -10,8 +10,8 @@
 
 #include "internal.h"
 
-Code_t ZSetFD(fd)
-	int	fd;
+Code_t
+ZSetFD(int fd)
 {
 	(void) ZClosePort();
 
