@@ -31,6 +31,7 @@
 #include "config.h"
 #include "debug.h"
 #include "libc_internal.h"
+#include "util.h"
 #include <glib/gstdio.h>
 
 /** This is redefined here because we can't include internal.h */
@@ -227,9 +228,11 @@ int wpurple_ioctl(int fd, int command, void* val) {
 			int i;
 			struct ifconf *ifc = val;
 			char *tmp = ifc->ifc_buf;
-			int nNumInterfaces =
-				nBytesReturned / sizeof(INTERFACE_INFO);
-			for (i = 0; i < nNumInterfaces; i++) {
+			int nReturnInterfaces = 0;
+
+			nReturnInterfaces = MIN(nBytesReturned / sizeof(INTERFACE_INFO),
+			                        ifc->ifc_len / sizeof(struct ifreq));
+			for (i = 0; i < nReturnInterfaces; i++) {
 				INTERFACE_INFO ii = InterfaceList[i];
 				struct ifreq *ifr = (struct ifreq *) tmp;
 				struct sockaddr_in *sa = (struct sockaddr_in *) &ifr->ifr_addr;
@@ -238,14 +241,9 @@ int wpurple_ioctl(int fd, int command, void* val) {
 				sa->sin_port = ii.iiAddress.AddressIn.sin_port;
 				sa->sin_addr.s_addr = ii.iiAddress.AddressIn.sin_addr.s_addr;
 				tmp += sizeof(struct ifreq);
-
-				/* Make sure that we can fit in the original buffer */
-				if (tmp >= (ifc->ifc_buf + ifc->ifc_len + sizeof(struct ifreq))) {
-					break;
-				}
 			}
 			/* Replace the length with the actually used length */
-			ifc->ifc_len = ifc->ifc_len - (ifc->ifc_buf - tmp);
+			ifc->ifc_len = nReturnInterfaces * sizeof(struct ifreq);
 			return 0;
 		}
 	}
@@ -933,7 +931,7 @@ wpurple_get_timezone_abbreviation(const struct tm *tm)
 
 	for (i = 0; win32_tzmap[i].wstd != NULL; i++)
 	{
-		if (strcmp(tzname, win32_tzmap[i].wstd) == 0)
+		if (purple_strequal(tzname, win32_tzmap[i].wstd))
 		{
 #if 0
 			purple_debug_info("wpurple", "TZ \"%s\" matches Windows timezone \"%s\"\n",
@@ -949,7 +947,7 @@ wpurple_get_timezone_abbreviation(const struct tm *tm)
 
 			return win32_tzmap[i].ustd;
 		}
-		if (strcmp(tzname, win32_tzmap[i].wdst) == 0)
+		if (purple_strequal(tzname, win32_tzmap[i].wdst))
 		{
 #if 0
 			purple_debug_info("wpurple", "TZ \"%s\" matches Windows timezone \"%s\"\n",
@@ -1023,7 +1021,7 @@ wpurple_get_timezone_abbreviation(const struct tm *tm)
 			RegCloseKey(key);
 			break;
 		}
-		if (strcmp(tzname, zonename) == 0)
+		if (purple_strequal(tzname, zonename))
 		{
 			/* Matched zone */
 			g_strlcpy(localtzname, keyname, sizeof(localtzname));
@@ -1038,7 +1036,7 @@ wpurple_get_timezone_abbreviation(const struct tm *tm)
 			RegCloseKey(key);
 			break;
 		}
-		if (strcmp(tzname, zonename) == 0)
+		if (purple_strequal(tzname, zonename))
 		{
 			/* Matched DST zone */
 			g_strlcpy(localtzname, keyname, sizeof(localtzname));
@@ -1056,7 +1054,7 @@ wpurple_get_timezone_abbreviation(const struct tm *tm)
 		/* Found a localized name, so scan for that one too */
 		for (i = 0; win32_tzmap[i].wstd != NULL; i++)
 		{
-			if (strcmp(localtzname, win32_tzmap[i].wstd) == 0)
+			if (purple_strequal(localtzname, win32_tzmap[i].wstd))
 			{
 #if 0
 				purple_debug_info("wpurple", "TZ \"%s\" matches localized Windows timezone \"%s\" (\"%s\")\n",
@@ -1070,7 +1068,7 @@ wpurple_get_timezone_abbreviation(const struct tm *tm)
 
 				return win32_tzmap[i].ustd;
 			}
-			if (strcmp(localtzname, win32_tzmap[i].wdst) == 0)
+			if (purple_strequal(localtzname, win32_tzmap[i].wdst))
 			{
 #if 0
 				purple_debug_info("wpurple", "TZ \"%s\" matches localized Windows timezone \"%s\" (\"%s\")\n",
