@@ -22,16 +22,26 @@
  */
 #ifndef _WIN32DEP_H_
 #define _WIN32DEP_H_
-#include <shlobj.h>
 #include <winsock2.h>
+#include <windows.h>
+#include <shlobj.h>
 #include <process.h>
 #include "wpurpleerror.h"
 #include "libc_interface.h"
 
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
 
+/* the winapi headers don't yet have winhttp.h, so we use the struct from msdn directly */
+typedef struct {
+  BOOL fAutoDetect;
+  LPWSTR lpszAutoConfigUrl;
+  LPWSTR lpszProxy;
+  LPWSTR lpszProxyBypass;
+} WINHTTP_CURRENT_USER_IE_PROXY_CONFIG;
+
 /* rpcndr.h defines small as char, causing problems, so we need to undefine it */
 #undef small
 
@@ -44,12 +54,11 @@ extern "C" {
  **/
 /* Windows helper functions */
 FARPROC wpurple_find_and_loadproc(const char *dllname, const char *procedure);
+gboolean wpurple_read_reg_dword(HKEY rootkey, const char *subkey, const char *valname, LPDWORD result);
 char *wpurple_read_reg_string(HKEY rootkey, const char *subkey, const char *valname); /* needs to be g_free'd */
 gboolean wpurple_write_reg_string(HKEY rootkey, const char *subkey, const char *valname, const char *value);
 char *wpurple_escape_dirsep(const char *filename); /* needs to be g_free'd */
 GIOChannel *wpurple_g_io_channel_win32_new_socket(int socket); /* Until we get the post-2.8 glib win32 giochannel implementation working, use the thread-based one */
-/** Check for changes to the system proxy settings and update the HTTP_PROXY env. var. if there have been changes */
-gboolean wpurple_check_for_proxy_changes(void);
 
 /* Determine Purple paths */
 gchar *wpurple_get_special_folder(int folder_type); /* needs to be g_free'd */
