@@ -36,6 +36,12 @@
 #include "gtkutils.h"
 #include "pidginstock.h"
 #include "gtkblist.h"
+#ifdef USE_VV
+#include "media-gst.h"
+#ifdef HAVE_GIOUNIX
+#include <gio/gunixfdlist.h>
+#endif
+#endif
 
 #include <gdk/gdkkeysyms.h>
 
@@ -77,6 +83,20 @@ typedef struct
 
 		} file;
 
+		struct
+		{
+#ifdef HAVE_GIOUNIX
+			GDBusConnection *dbus_connection;
+#endif
+			GCancellable *cancellable;
+			gchar *session_path;
+			guint signal_id;
+			guint32 node_id;
+			guint portal_session_nr;
+			guint portal_request_nr;
+
+		} screenshare;
+
 	} u;
 
 } PidginRequestData;
@@ -1703,6 +1723,727 @@ pidgin_request_folder(const char *title, const char *dirname,
 	return (void *)data;
 }
 
+#ifdef USE_VV
+
+#ifdef HAVE_GIOUNIX
+
+static gboolean portal_failed;
+
+static void screenshare_cancel_cb(GtkWidget *button, PidginRequestData *data);
+
+static void portal_fallback(PidginRequestData *data)
+{
+	purple_debug_info("pidgin", "Fallback from XDP portal screenshare\n");
+	portal_failed = TRUE;
+
+	if (data->dialog) {
+		pidgin_auto_parent_window(data->dialog);
+		gtk_widget_show_all(data->dialog);
+	} else {
+		screenshare_cancel_cb(NULL, data);
+	}
+}
+
+static void request_completed_cb(GObject *object, GAsyncResult *res, gpointer _data)
+{
+	PidginRequestData *data = _data;
+	GError *error = NULL;
+	GDBusMessage *msg = g_dbus_connection_send_message_with_reply_finish(data->u.screenshare.dbus_connection,
+									     res,
+									     &error);
+	if (!msg || g_dbus_message_to_gerror(msg, &error)) {
+		/* This is the expected failure mode when XDP screencast isn't available.
+		 * Don't be too noisy about it; just fall back to direct mode. */
+		purple_debug_info("pidgin",
+				  "ScreenCast call failed: %s\n", error->message);
+		portal_fallback(data);
+	}
+}
+
+static gchar *portal_request_path(PidginRequestData *data, GVariantBuilder *b)
+{
+	const gchar *bus_name;
+	gchar *dot, *request_str;
+	gchar *request_path;
+
+	bus_name = g_dbus_connection_get_unique_name(data->u.screenshare.dbus_connection);
+
+	request_str = g_strdup_printf("u%u", data->u.screenshare.portal_request_nr++);
+	if (!request_str) {
+		return NULL;
+	}
+
+	request_path = g_strdup_printf("/org/freedesktop/portal/desktop/request/%s/%s",
+				       bus_name + 1, request_str);
+	if (!request_path) {
+		g_free(request_str);
+		return NULL;
+	}
+
+	g_variant_builder_add(b, "{sv}", "handle_token", g_variant_new_take_string(request_str));
+
+	dot = request_path;
+	while ((dot = strchr(dot, '.'))) {
+		*dot = '_';
+	}
+
+	return request_path;
+}
+
+static void screen_cast_call(PidginRequestData *data, const gchar *method, const gchar *str_arg,
+			     GVariantBuilder *opts, GDBusSignalCallback cb)
+{
+	GDBusMessage *msg;
+	GVariantBuilder b;
+	gchar *request_path;
+
+	if (data->u.screenshare.signal_id) {
+		g_dbus_connection_signal_unsubscribe(data->u.screenshare.dbus_connection,
+						     data->u.screenshare.signal_id);
+	}
+
+	if (!opts) {
+		opts = g_variant_builder_new(G_VARIANT_TYPE("a{sv}"));
+	}
+
+	request_path = portal_request_path(data, opts);
+	if (!request_path) {
+		g_variant_builder_unref(opts);
+		purple_notify_error(NULL, _("Screen share error"),
+				    _("Error creating screencast request"), NULL);
+		screenshare_cancel_cb(NULL, data);
+	}
+
+	data->u.screenshare.signal_id = g_dbus_connection_signal_subscribe(data->u.screenshare.dbus_connection,
+									   "org.freedesktop.portal.Desktop",
+									   "org.freedesktop.portal.Request",
+									   "Response", request_path, NULL, 0,
+									   cb, data, NULL);
+	g_free(request_path);
+
+	msg = g_dbus_message_new_method_call("org.freedesktop.portal.Desktop",
+					     "/org/freedesktop/portal/desktop",
+					     "org.freedesktop.portal.ScreenCast",
+					     method);
+
+	g_variant_builder_init(&b, G_VARIANT_TYPE_TUPLE);
+	if (data->u.screenshare.session_path) {
+		g_variant_builder_add(&b, "o", data->u.screenshare.session_path);
+	}
+	if (str_arg) {
+		g_variant_builder_add(&b, "s", str_arg);
+	}
+	g_variant_builder_add(&b, "a{sv}", opts);
+
+	g_dbus_message_set_body(msg, g_variant_builder_end(&b));
+
+	g_dbus_connection_send_message_with_reply(data->u.screenshare.dbus_connection, msg,
+						  0, 2000, NULL, NULL, request_completed_cb, data);
+}
+
+static GstElement *create_pipewiresrc_cb(PurpleMedia *media, const gchar *session_id,
+					 const gchar *participant)
+{
+	GstElement *ret;
+	GObject *info;
+	gchar *node_id;
+
+	info = g_object_get_data(G_OBJECT(media), "src-element");
+	if (!info) {
+		return NULL;
+	}
+
+	ret = gst_element_factory_make("pipewiresrc", NULL);
+	if (ret == NULL) {
+		return NULL;
+	}
+
+	/* Take the node-id and fd from the PurpleMediaElementInfo
+	 * and apply them to the pipewiresrc */
+	node_id = g_strdup_printf("%u",
+				  GPOINTER_TO_UINT(g_object_get_data(info, "node-id")));
+	g_object_set(ret,"path", node_id, "do-timestamp", TRUE,
+		     "fd", GPOINTER_TO_INT(g_object_get_data(info, "fd")),
+		     NULL);
+	g_free(node_id);
+
+	return ret;
+}
+
+static void close_pipewire_fd(gpointer _fd)
+{
+	int fd = GPOINTER_TO_INT(_fd);
+
+	close(fd);
+}
+
+static void pipewire_fd_cb(GObject *object, GAsyncResult *res, gpointer _data)
+{
+	PidginRequestData *data = _data;
+	GError *error = NULL;
+	GUnixFDList *l;
+	int pipewire_fd;
+	GDBusMessage *msg = g_dbus_connection_send_message_with_reply_finish(data->u.screenshare.dbus_connection,
+									     res,
+									     &error);
+	if (!msg || g_dbus_message_to_gerror(msg, &error)) {
+		purple_debug_info("pidgin", "OpenPipeWireRemote request failed: %s\n", error->message);
+		purple_notify_error(NULL, _("Screen share error"),
+				    _("OpenPipeWireRemote request failed"), error->message);
+		g_clear_error(&error);
+		screenshare_cancel_cb(NULL, data);
+		return;
+	}
+	l = g_dbus_message_get_unix_fd_list(msg);
+	if (!l) {
+		purple_debug_info("pidgin", "OpenPipeWireRemote request failed to yield a file descriptor\n");
+		purple_notify_error(NULL, _("Screen share error"), _("OpenPipeWireRemote request failed"),
+				    _("No file descriptor found"));
+		screenshare_cancel_cb(NULL, data);
+		return;
+	}
+	pipewire_fd = g_unix_fd_list_get(l, 0, NULL);
+
+	if (data->cbs[0] != NULL) {
+		GObject *info;
+		info = g_object_new(PURPLE_TYPE_MEDIA_ELEMENT_INFO,
+				    "id", "screenshare-window",
+				    "name", "Screen share single window",
+				    "type", PURPLE_MEDIA_ELEMENT_VIDEO | PURPLE_MEDIA_ELEMENT_SRC |
+				    PURPLE_MEDIA_ELEMENT_ONE_SRC,
+				    "create-cb", create_pipewiresrc_cb, NULL);
+		g_object_set_data_full(info, "fd", GINT_TO_POINTER(pipewire_fd), close_pipewire_fd);
+		g_object_set_data(info, "node-id", GUINT_TO_POINTER(data->u.screenshare.node_id));
+		/* When the DBus connection closes, the session ends. So keep it attached
+		   to the PurpleMediaElementInfo, which in turn should be attached to
+		   the owning PurpleMedia for the lifetime of the session. */
+		g_object_set_data_full(info, "dbus-connection",
+				       g_object_ref(data->u.screenshare.dbus_connection),
+				       g_object_unref);
+		((PurpleRequestScreenshareCb)data->cbs[0])(data->user_data, info);
+	}
+
+	purple_request_close(PURPLE_REQUEST_SCREENSHARE, data);
+}
+
+
+static void get_pipewire_fd(PidginRequestData *data)
+{
+	GDBusMessage *msg;
+	GVariant *args;
+
+	if (data->u.screenshare.signal_id) {
+		g_dbus_connection_signal_unsubscribe(data->u.screenshare.dbus_connection,
+						     data->u.screenshare.signal_id);
+	}
+	data->u.screenshare.signal_id = 0;
+
+	msg = g_dbus_message_new_method_call("org.freedesktop.portal.Desktop",
+					     "/org/freedesktop/portal/desktop",
+					     "org.freedesktop.portal.ScreenCast",
+					     "OpenPipeWireRemote");
+
+	args = g_variant_new("(oa{sv})", data->u.screenshare.session_path, NULL);
+	g_dbus_message_set_body(msg, args);
+
+	g_dbus_connection_send_message_with_reply(data->u.screenshare.dbus_connection, msg,
+						  0, 200, NULL, NULL, pipewire_fd_cb, data);
+}
+
+static void started_cb(GDBusConnection *dc, const gchar *sender_name,
+		       const gchar *object_path, const gchar *interface_name,
+		       const gchar *signal_name, GVariant *params, gpointer _data)
+{
+	PidginRequestData *data = _data;
+	GVariant *args, *streams;
+	guint code;
+
+	g_variant_get(params, "(u@a{sv})", &code, &args);
+	if (code || !g_variant_lookup(args, "streams", "@a(ua{sv})", &streams) ||
+	    g_variant_n_children(streams) != 1) {
+		purple_debug_info("pidgin", "Screencast Start call returned %d\n", code);
+		purple_notify_error(NULL, _("Screen share error"),
+				    _("Screencast \"Start\" failed"), NULL);
+		screenshare_cancel_cb(NULL, data);
+		return;
+	}
+
+	g_variant_get_child(streams, 0, "(u@a{sv})", &data->u.screenshare.node_id, NULL);
+
+	get_pipewire_fd(data);
+}
+
+static void source_selected_cb(GDBusConnection *dc, const gchar *sender_name,
+			       const gchar *object_path, const gchar *interface_name,
+			       const gchar *signal_name, GVariant *params, gpointer _data)
+{
+	PidginRequestData *data = _data;
+	guint code;
+
+	g_variant_get(params, "(u@a{sv})", &code, NULL);
+	if (code) {
+		purple_debug_info("pidgin", "Screencast SelectSources call returned %d\n", code);
+		purple_notify_error(NULL, _("Screen share error"),
+				    _("Screencast \"SelectSources\" failed"), NULL);
+		screenshare_cancel_cb(NULL, data);
+		return;
+	}
+
+	screen_cast_call(data, "Start", "", NULL, started_cb);
+}
+
+static void sess_created_cb(GDBusConnection *dc, const gchar *sender_name,
+			    const gchar *object_path, const gchar *interface_name,
+			    const gchar *signal_name, GVariant *params, gpointer _data)
+{
+	PidginRequestData *data = _data;
+	GVariantBuilder opts;
+	GVariant *args;
+	guint code;
+
+	g_variant_get(params, "(u@a{sv})", &code, &args);
+	if (code || !g_variant_lookup(args, "session_handle", "s",
+				      &data->u.screenshare.session_path)) {
+		purple_debug_info("pidgin", "Screencast CreateSession call returned %d\n", code);
+		purple_notify_error(NULL, _("Screen share error"),
+				    _("Screencast \"CreateSession\" failed."), NULL);
+		screenshare_cancel_cb(NULL, data);
+		return;
+	}
+
+	g_variant_builder_init(&opts, G_VARIANT_TYPE("a{sv}"));
+	g_variant_builder_add(&opts, "{sv}", "multiple", g_variant_new_boolean(FALSE));
+	g_variant_builder_add(&opts, "{sv}", "types", g_variant_new_uint32(3));
+
+	screen_cast_call(data, "SelectSources", NULL, &opts, source_selected_cb);
+}
+
+static void portal_conn_cb(GObject *object, GAsyncResult *res, gpointer _data)
+{
+	PidginRequestData *data = _data;
+	GVariantBuilder opts;
+	GError *error = NULL;
+	gchar *session_token;
+
+	data->u.screenshare.dbus_connection = g_dbus_connection_new_for_address_finish(res, &error);
+	if (!data->u.screenshare.dbus_connection) {
+		purple_debug_info("pidgin", "Connection to XDP portal failed: %s\n", error->message);
+		portal_fallback(data);
+		return;
+	}
+
+	session_token = g_strdup_printf("u%u", data->u.screenshare.portal_session_nr++);
+
+	g_variant_builder_init(&opts, G_VARIANT_TYPE("a{sv}"));
+	g_variant_builder_add(&opts, "{sv}", "session_handle_token",
+			      g_variant_new_take_string(session_token));
+
+	screen_cast_call(data, "CreateSession", NULL, &opts, sess_created_cb);
+}
+
+static gboolean request_xdp_portal_screenshare(PidginRequestData *data)
+{
+	gchar *addr;
+
+	if (portal_failed) {
+		return FALSE;
+	}
+
+	data->u.screenshare.cancellable = g_cancellable_new();
+
+	/* We create a new connection instead of using g_bus_get() because it
+	 * makes cleanup a *lot* easier. Just kill the connection. */
+	addr = g_dbus_address_get_for_bus_sync(G_BUS_TYPE_SESSION, NULL, NULL);
+	if (!addr) {
+		portal_failed = TRUE;
+		return FALSE;
+	}
+
+	g_dbus_connection_new_for_address(addr,
+					  G_DBUS_CONNECTION_FLAGS_MESSAGE_BUS_CONNECTION |
+					  G_DBUS_CONNECTION_FLAGS_AUTHENTICATION_CLIENT, NULL,
+					  data->u.screenshare.cancellable, portal_conn_cb, data);
+	g_free(addr);
+	return TRUE;
+}
+
+#endif
+
+static GstElement *create_screensrc_cb(PurpleMedia *media, const gchar *session_id,
+				       const gchar *participant);
+
+#ifdef HAVE_X11
+static gboolean
+grab_event (GtkWidget *child, GdkEvent *event, PidginRequestData *data)
+{
+	GdkScreen *screen = gdk_screen_get_default();
+	GObject *info;
+	GdkWindow *gdkroot = gdk_get_default_root_window();
+	Window xroot = GDK_WINDOW_XID(gdkroot), xwindow, parent, *children;
+	unsigned int nchildren, xmask;
+	Display *xdisplay = GDK_SCREEN_XDISPLAY(screen);
+	int rootx, rooty, winx, winy;
+
+	if (event->type != GDK_BUTTON_PRESS)
+		return FALSE;
+
+	XQueryPointer(xdisplay, xroot, &xroot, &xwindow, &rootx, &rooty, &winx, &winy, &xmask);
+
+	gdk_pointer_ungrab(GDK_CURRENT_TIME);
+
+	/* Find WM window (direct child of root) */
+	while (1) {
+		if (!XQueryTree(xdisplay, xwindow, &xroot, &parent, &children, &nchildren))
+			break;
+
+		if (nchildren)
+			XFree(children);
+
+		if (xroot == parent)
+			break;
+
+		xwindow = parent;
+	}
+
+	generic_response_start(data);
+
+	if (data->cbs[0] != NULL) {
+		info = g_object_new(PURPLE_TYPE_MEDIA_ELEMENT_INFO,
+				    "id", "screenshare-window",
+				    "name", "Screen share single window",
+				    "type", PURPLE_MEDIA_ELEMENT_VIDEO | PURPLE_MEDIA_ELEMENT_SRC |
+				    PURPLE_MEDIA_ELEMENT_ONE_SRC,
+				    "create-cb", create_screensrc_cb, NULL);
+		g_object_set_data(info, "window-id", GUINT_TO_POINTER(xwindow));
+		((PurpleRequestScreenshareCb)data->cbs[0])(data->user_data, info);
+	}
+
+	purple_request_close(PURPLE_REQUEST_SCREENSHARE, data);
+
+	return FALSE;
+}
+
+static void
+screenshare_window_cb(GtkWidget *button, PidginRequestData *data)
+{
+	GdkCursor *cursor;
+	GdkWindow *gdkwin = gtk_widget_get_window(GTK_WIDGET(data->dialog));
+
+	if (!GTK_WIDGET_HAS_FOCUS(button))
+		gtk_widget_grab_focus(button);
+
+	gtk_widget_add_events(GTK_WIDGET(data->dialog),
+			      GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK);
+	g_signal_connect(data->dialog, "event", G_CALLBACK(grab_event), data);
+
+	cursor = gdk_cursor_new(GDK_CROSSHAIR);
+	gdk_pointer_grab(gdkwin, FALSE,
+			 GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK,
+			 NULL, cursor, GDK_CURRENT_TIME);
+}
+
+static GstElement *create_screensrc_cb(PurpleMedia *media, const gchar *session_id,
+				       const gchar *participant)
+{
+	GObject *info;
+	GstElement *ret;
+
+	ret = gst_element_factory_make("ximagesrc", NULL);
+	if (ret == NULL)
+		return NULL;
+
+	g_object_set(ret, "use-damage", 0, NULL);
+
+	info = g_object_get_data(G_OBJECT(media), "src-element");
+	if (info) {
+		Window xid = GPOINTER_TO_UINT(g_object_get_data(info, "window-id"));
+		int monitor_no = GPOINTER_TO_INT(g_object_get_data(info, "monitor-no"));
+		if (xid) {
+			g_object_set(ret, "xid", xid, NULL);
+		} else if (monitor_no >= 0) {
+			GdkScreen *screen = gdk_screen_get_default();
+			GdkRectangle geom;
+
+			gdk_screen_get_monitor_geometry(screen, monitor_no, &geom);
+			g_object_set(ret, "startx", geom.x, "starty", geom.y,
+				     "endx", geom.x + geom.width - 1,
+				     "endy", geom.y + geom.height - 1, NULL);
+		}
+	}
+
+	return ret;
+}
+#elif defined (_WIN32)
+static GstElement *create_screensrc_cb(PPurpleMedia *media, const gchar *session_id,
+				       const gchar *participant)
+{
+	GObject *info;
+	GstElement *ret;
+
+	ret = gst_element_factory_make("gdiscreencapsrc", NULL);
+	if (ret == NULL)
+		return NULL;
+
+	g_object_set(ret, "cursor", TRUE);
+
+	info = g_object_get_data(G_OBJECT(media), "src-element");
+	if (info) {
+		int monitor_no = GPOINTER_TO_INT(g_object_get_data(info, "monitor-no"));
+		if (monitor_no >= 0)
+			g_object_set(ret, "monitor", monitor_no);
+	}
+
+	return ret;
+}
+#else
+/* We don't actually need to break the build just because we can't do
+ * screencap, but gtkmedia.c is going to break the USE_VV build if it
+ * isn't WIN32 or X11 anyway, so we might as well. */
+#error "Unsupported windowing system"
+#endif
+
+static void
+screenshare_monitor_cb(GtkWidget *button, PidginRequestData *data)
+{
+	GtkWidget *radio;
+	GObject *info;
+	int monitor_no = -1;
+
+	generic_response_start(data);
+
+	if (!GTK_WIDGET_HAS_FOCUS(button))
+		gtk_widget_grab_focus(button);
+
+	radio = g_object_get_data(G_OBJECT(data->dialog), "radio");
+	if (radio) {
+		GSList *group = gtk_radio_button_get_group(GTK_RADIO_BUTTON(radio));
+
+		while (group) {
+			if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(group->data))) {
+				monitor_no = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(group->data),
+									       "monitor-no"));
+				break;
+			}
+			group = group->next;
+		}
+	}
+	if (data->cbs[0] != NULL) {
+		info = g_object_new(PURPLE_TYPE_MEDIA_ELEMENT_INFO,
+				    "id", "screenshare-monitor",
+				    "name", "Screen share monitor",
+				    "type", PURPLE_MEDIA_ELEMENT_VIDEO | PURPLE_MEDIA_ELEMENT_SRC |
+				    PURPLE_MEDIA_ELEMENT_ONE_SRC,
+				    "create-cb", create_screensrc_cb, NULL);
+		g_object_set_data(info, "monitor-no", GINT_TO_POINTER(monitor_no));
+		((PurpleRequestScreenshareCb)data->cbs[0])(data->user_data, info);
+	}
+
+	purple_request_close(PURPLE_REQUEST_SCREENSHARE, data);
+}
+
+static GstElement *create_videotest_cb(PurpleMedia *media, const gchar *session_id,
+				       const gchar *participant)
+{
+	return gst_element_factory_make("videotestsrc", NULL);
+}
+
+static void
+screenshare_videotest_cb(GtkWidget *button, PidginRequestData *data)
+{
+	GObject *info;
+
+	generic_response_start(data);
+
+	if (!GTK_WIDGET_HAS_FOCUS(button))
+		gtk_widget_grab_focus(button);
+
+	if (data->cbs[0] != NULL) {
+		info = g_object_new(PURPLE_TYPE_MEDIA_ELEMENT_INFO,
+				    "id", "screenshare-videotestsrc",
+				    "name", "Screen share test source",
+				    "type", PURPLE_MEDIA_ELEMENT_VIDEO | PURPLE_MEDIA_ELEMENT_SRC |
+				    PURPLE_MEDIA_ELEMENT_ONE_SRC,
+				    "create-cb", create_videotest_cb, NULL);
+		((PurpleRequestScreenshareCb)data->cbs[0])(data->user_data, info);
+	}
+
+	purple_request_close(PURPLE_REQUEST_SCREENSHARE, data);
+}
+
+static void
+screenshare_cancel_cb(GtkWidget *button, PidginRequestData *data)
+{
+	if (data->dialog) {
+		generic_response_start(data);
+	}
+
+	if (data->cbs[0] != NULL)
+		((PurpleRequestScreenshareCb)data->cbs[0])(data->user_data, NULL);
+
+	purple_request_close(PURPLE_REQUEST_SCREENSHARE, data);
+}
+
+static gboolean
+destroy_screenshare_cb(GtkWidget *dialog, GdkEvent *event,
+		       PidginRequestData *data)
+{
+	screenshare_cancel_cb(NULL, data);
+	return FALSE;
+}
+
+static void *pidgin_request_screenshare_media(const char *title, const char *primary,
+					      const char *secondary, PurpleAccount *account,
+					      GCallback cb, void *user_data)
+{
+	PidginRequestData *data;
+	GtkWidget *dialog;
+	GtkWidget *vbox;
+	GtkWidget *hbox;
+	GtkWidget *label;
+	GtkWidget *button;
+	GtkWidget *radio = NULL;
+	GdkScreen *screen;
+	char *label_text;
+	char *primary_esc, *secondary_esc;
+
+	data            = g_new0(PidginRequestData, 1);
+	data->type      = PURPLE_REQUEST_SCREENSHARE;
+	data->user_data = user_data;
+
+	data->cb_count = 1;
+	data->cbs = g_new0(GCallback, 1);
+	data->cbs[0] = cb;
+
+	/* Create the dialog. */
+	data->dialog = dialog = gtk_dialog_new();
+
+	if (title != NULL)
+		gtk_window_set_title(GTK_WINDOW(dialog), title);
+#ifdef _WIN32
+	else
+		gtk_window_set_title(GTK_WINDOW(dialog), PIDGIN_ALERT_TITLE);
+#endif
+
+	button = pidgin_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CANCEL,
+					  G_CALLBACK(screenshare_cancel_cb), data);
+	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+
+	if (g_getenv("PIDGIN_SHARE_VIDEOTEST") != NULL) {
+		button = pidgin_dialog_add_button(GTK_DIALOG(dialog), _("Test image"),
+						  G_CALLBACK(screenshare_videotest_cb), data);
+		GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+		gtk_window_set_default(GTK_WINDOW(dialog), button);
+	}
+
+#ifdef HAVE_X11
+	button = pidgin_dialog_add_button(GTK_DIALOG(dialog), _("Select window"),
+					  G_CALLBACK(screenshare_window_cb), data);
+	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+	gtk_window_set_default(GTK_WINDOW(dialog), button);
+#endif
+
+	button = pidgin_dialog_add_button(GTK_DIALOG(dialog), _("Use monitor"),
+					  G_CALLBACK(screenshare_monitor_cb), data);
+	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+	gtk_window_set_default(GTK_WINDOW(dialog), button);
+
+	g_signal_connect(G_OBJECT(dialog), "delete_event",
+					 G_CALLBACK(destroy_screenshare_cb), data);
+
+	/* Setup the dialog */
+	gtk_container_set_border_width(GTK_CONTAINER(dialog), PIDGIN_HIG_BORDER/2);
+	gtk_container_set_border_width(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), PIDGIN_HIG_BORDER/2);
+	gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
+	gtk_dialog_set_has_separator(GTK_DIALOG(dialog), FALSE);
+	gtk_box_set_spacing(GTK_BOX(GTK_DIALOG(dialog)->vbox), PIDGIN_HIG_BORDER);
+
+	/* Setup the main horizontal box */
+	hbox = gtk_hbox_new(FALSE, PIDGIN_HIG_BORDER);
+	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), hbox);
+
+
+	/* Vertical box */
+	vbox = gtk_vbox_new(FALSE, PIDGIN_HIG_BORDER);
+	gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
+
+	pidgin_widget_decorate_account(hbox, account);
+
+	/* Descriptive label */
+	primary_esc = (primary != NULL) ? g_markup_escape_text(primary, -1) : NULL;
+	secondary_esc = (secondary != NULL) ? g_markup_escape_text(secondary, -1) : NULL;
+	label_text = g_strdup_printf((primary ? "<span weight=\"bold\" size=\"larger\">"
+								 "%s</span>%s%s" : "%s%s%s"),
+								 (primary ? primary_esc : ""),
+								 ((primary && secondary) ? "\n\n" : ""),
+								 (secondary ? secondary_esc : ""));
+	g_free(primary_esc);
+	g_free(secondary_esc);
+
+	label = gtk_label_new(NULL);
+
+	gtk_label_set_markup(GTK_LABEL(label), label_text);
+	gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
+	gtk_misc_set_alignment(GTK_MISC(label), 0, 0);
+	gtk_label_set_selectable(GTK_LABEL(label), TRUE);
+	gtk_box_pack_start(GTK_BOX(vbox), label, TRUE, TRUE, 0);
+
+	g_free(label_text);
+
+	screen = gdk_screen_get_default();
+	if (screen) {
+		int nr_monitors = gdk_screen_get_n_monitors(screen);
+		int primary = gdk_screen_get_primary_monitor(screen);
+		int i;
+
+		for (i = 0; i < nr_monitors; i++) {
+			GdkRectangle geom;
+			gchar *name;
+			gchar *label;
+
+			name = gdk_screen_get_monitor_plug_name(screen, i);
+			gdk_screen_get_monitor_geometry(screen, i, &geom);
+
+			label = g_strdup_printf(_("%s (%d✕%d @ %d,%d)"),
+						name ? name : _("Unknown output"),
+						geom.width, geom.height,
+						geom.x, geom.y);
+			radio = gtk_radio_button_new_with_label_from_widget((GtkRadioButton *)radio, label);
+			g_object_set_data(G_OBJECT(radio), "monitor-no", GINT_TO_POINTER(i));
+			gtk_box_pack_start(GTK_BOX(vbox), radio, FALSE, FALSE, 0);
+			if (i == primary)
+			       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), TRUE);
+
+			g_free(label);
+			g_free(name);
+		}
+		g_object_set_data(G_OBJECT(dialog), "radio", radio);
+	}
+
+#ifdef HAVE_GIOUNIX
+	/*
+	 * We create the dialog for direct x11/win share here anyway, because
+	 * it's simpler than storing everything we need to create it, including
+	 * the PurpleAccount which we can't just take a ref on because it isn't
+	 * just a GObject yet. On fallback, the dialog can be used immediately.
+	 */
+	if (request_xdp_portal_screenshare(data)) {
+		purple_debug_info("pidgin", "Attempt XDP portal screenshare\n");
+		return data;
+	}
+#endif
+
+	purple_debug_info("pidgin", "Using direct screenshare\n");
+
+	/* Show everything. */
+	pidgin_auto_parent_window(dialog);
+
+	gtk_widget_show_all(dialog);
+
+	return data;
+
+}
+#endif /* USE_VV */
+
 static void
 pidgin_close_request(PurpleRequestType type, void *ui_handle)
 {
@@ -1710,12 +2451,25 @@ pidgin_close_request(PurpleRequestType type, void *ui_handle)
 
 	g_free(data->cbs);
 
-	gtk_widget_destroy(data->dialog);
+	if (data->dialog) {
+		gtk_widget_destroy(data->dialog);
+	}
 
-	if (type == PURPLE_REQUEST_FIELDS)
+	if (type == PURPLE_REQUEST_FIELDS) {
 		purple_request_fields_destroy(data->u.multifield.fields);
-	else if (type == PURPLE_REQUEST_FILE)
+	} else if (type == PURPLE_REQUEST_FILE) {
 		g_free(data->u.file.name);
+	} else if (type == PURPLE_REQUEST_SCREENSHARE) {
+#ifdef HAVE_GIOUNIX
+		g_cancellable_cancel(data->u.screenshare.cancellable);
+		if (data->u.screenshare.signal_id)
+			g_dbus_connection_signal_unsubscribe(data->u.screenshare.dbus_connection,
+							     data->u.screenshare.signal_id);
+		g_clear_object(&data->u.screenshare.dbus_connection);
+		g_free(data->u.screenshare.session_path);
+		g_clear_object(&data->u.screenshare.cancellable);
+#endif
+	}
 
 	g_free(data);
 }
@@ -1730,7 +2484,11 @@ static PurpleRequestUiOps ops =
 	pidgin_close_request,
 	pidgin_request_folder,
 	pidgin_request_action_with_icon,
+#ifdef USE_VV
+	pidgin_request_screenshare_media,
+#else
 	NULL,
+#endif
 	NULL,
 	NULL
 };
