@@ -82,7 +82,7 @@ static struct
 	PurpleMessageFlags flag;
 	char *prefix;
 	const char *text;
-} formats[] = 
+} formats[] =
 {
 	{PURPLE_MESSAGE_ERROR, PREF_ERROR, N_("Error Messages")},
 	{PURPLE_MESSAGE_NICK, PREF_NICK, N_("Highlighted Messages")},
@@ -198,7 +198,12 @@ color_response(GtkDialog *color_dialog, gint response, const char *data)
 {
 	if (response == GTK_RESPONSE_OK)
 	{
+#if GTK_CHECK_VERSION(2,14,0)
+		GtkWidget *colorsel =
+			gtk_color_selection_dialog_get_color_selection(GTK_COLOR_SELECTION_DIALOG(color_dialog));
+#else
 		GtkWidget *colorsel = GTK_COLOR_SELECTION_DIALOG(color_dialog)->colorsel;
+#endif
 		GdkColor color;
 		char colorstr[8];
 		char tmp[128];
@@ -232,8 +237,15 @@ set_color(GtkWidget *widget, const char *data)
 	g_snprintf(tmp, sizeof(tmp), "%s/color", data);
 	if (gdk_color_parse(purple_prefs_get_string(tmp), &color))
 	{
+#if GTK_CHECK_VERSION(2,14,0)
+		gtk_color_selection_set_current_color(GTK_COLOR_SELECTION(
+			gtk_color_selection_dialog_get_color_selection(GTK_COLOR_SELECTION_DIALOG(color_dialog))),
+			&color);
+#else
 		gtk_color_selection_set_current_color(
-				GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(color_dialog)->colorsel), &color);
+			GTK_COLOR_SELECTION(GTK_COLOR_SELECTION_DIALOG(color_dialog)->colorsel),
+			&color);
+#endif
 	}
 
 	gtk_window_present(GTK_WINDOW(color_dialog));
@@ -381,7 +393,7 @@ get_config_frame(PurplePlugin *plugin)
 	return ret;
 }
 
-static PidginPluginUiInfo ui_info = 
+static PidginPluginUiInfo ui_info =
 {
 	get_config_frame,
 	0,
