@@ -57,11 +57,7 @@ switch_page(PidginWindow *win, GtkDirectionType dir)
 {
 	int count, current;
 
-#if GTK_CHECK_VERSION(2,2,0)
 	count = gtk_notebook_get_n_pages(GTK_NOTEBOOK(win->notebook));
-#else
-	count = g_list_length(GTK_NOTEBOOK(win->notebook)->children);
-#endif
 	current = gtk_notebook_get_current_page(GTK_NOTEBOOK(win->notebook));
 
 	if (dir == GTK_DIR_LEFT)
@@ -149,6 +145,15 @@ new_conv_cb(PurpleConversation *conv)
 }
 
 #if 0
+#if GTK_CHECK_VERSION(2,4,0)
+static void
+mouse_button_menu_cb(GtkComboBox *opt, gpointer data)
+{
+	int button = gtk_combo_box_get_active(opt);
+
+	gstroke_set_mouse_button(button + 2);
+}
+#else
 static void
 mouse_button_menu_cb(GtkMenuItem *item, gpointer data)
 {
@@ -157,6 +162,7 @@ mouse_button_menu_cb(GtkMenuItem *item, gpointer data)
 	gstroke_set_mouse_button(button + 2);
 }
 #endif
+#endif
 
 static void
 toggle_draw_cb(GtkToggleButton *toggle, gpointer data)
@@ -224,7 +230,9 @@ get_config_frame(PurplePlugin *plugin)
 	GtkWidget *toggle;
 #if 0
 	GtkWidget *opt;
+#if GTK_CHECK_VERSION(2,4,0)
 	GtkWidget *menu, *item;
+#endif
 #endif
 
 	/* Outside container */
@@ -235,6 +243,19 @@ get_config_frame(PurplePlugin *plugin)
 	vbox = pidgin_make_frame(ret, _("Mouse Gestures Configuration"));
 
 #if 0
+#if GTK_CHECK_VERSION(2,4,0)
+	/* Mouse button drop-down menu */
+	opt = gtk_combo_box_new_text();
+
+	gtk_combo_box_append_text(_("Middle mouse button"));
+	gtk_combo_box_append_text(_("Right mouse button"));
+	g_signal_connect(G_OBJECT(opt), "changed",
+	                 G_CALLBACK(mouse_button_menu_cb), NULL);
+
+	gtk_box_pack_start(GTK_BOX(vbox), opt, FALSE, FALSE, 0);
+	gtk_combo_box_set_active(GTK_COMBO_BOX(opt),
+							gstroke_get_mouse_button() - 2);
+#else
 	/* Mouse button drop-down menu */
 	menu = gtk_menu_new();
 	opt = gtk_option_menu_new();
@@ -253,6 +274,7 @@ get_config_frame(PurplePlugin *plugin)
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(opt), menu);
 	gtk_option_menu_set_history(GTK_OPTION_MENU(opt),
 								gstroke_get_mouse_button() - 2);
+#endif
 #endif
 
 	/* "Visual gesture display" checkbox */
@@ -297,12 +319,12 @@ static PurplePluginInfo info =
 	                                                  /**  summary        */
 	N_("Provides support for mouse gestures"),
 	                                                  /**  description    */
-	N_("Allows support for mouse gestures in conversation windows.\n"
-	   "Drag the middle mouse button to perform certain actions:\n\n"
-	   "Drag down and then to the right to close a conversation.\n"
-	   "Drag up and then to the left to switch to the previous "
+	N_("Allows support for mouse gestures in conversation windows. "
+	   "Drag the middle mouse button to perform certain actions:\n"
+	   " • Drag down and then to the right to close a conversation.\n"
+	   " • Drag up and then to the left to switch to the previous "
 	   "conversation.\n"
-	   "Drag up and then to the right to switch to the next "
+	   " • Drag up and then to the right to switch to the next "
 	   "conversation."),
 	"Christian Hammond <chipx86@gnupdate.org>",       /**< author         */
 	PURPLE_WEBSITE,                                     /**< homepage       */
